@@ -25,12 +25,12 @@ void LiquidCrystalClass::elaborate( MethodDescriptor* m ) {
             }
             else
                 v[m->getObjectId()]->print(m->getString(0));
-            m->returns("0");
+            m->returns(0);
         }
 
         if (strcmp(m->getName(), "setCursor") == 0) {
             v[m->getObjectId()]->setCursor(m->getInt(0), m->getInt(1));
-            m->returns("0");
+            m->returns(0);
         }
 
     }
