@@ -15,12 +15,12 @@ void ToneClass::elaborate( MethodDescriptor* m ) {
 
         if (strcmp(m->getName(), "play") == 0) {
             v[m->getObjectId()]->play(m->getInt(0), m->getInt(0));
-            m->returns("0");
+            m->returns(0);
         }
 
         if (strcmp(m->getName(), "stop") == 0) {
             v[m->getObjectId()]->stop();
-            m->returns("0");
+            m->returns(0);
         }
 
     }
