@@ -1,16 +1,17 @@
 from nanpy.arduinoboard import ArduinoObject
-from nanpy.arduinoboard import (arduinoobjectmethod, returnint)
+from nanpy.arduinoboard import (arduinoobjectmethod, returns)
 
 class Servo(ArduinoObject):
 
     def __init__(self, pin):
+        ArduinoObject.__init__(self)
         self.id = self.call('new', pin)
 
     @arduinoobjectmethod
     def write(self, value):
         pass
 
-    @returnint
+    @returns(int)
     @arduinoobjectmethod
     def read(self):
         pass
@@ -19,7 +20,7 @@ class Servo(ArduinoObject):
     def writeMicroseconds(self, value):
         pass
 
-    @returnint
+    @returns(int)
     @arduinoobjectmethod
     def readMicroseconds(self, value):
         pass
